@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Return the borders of states and provinces
 
-our $VERSION = '0.0103';
+our $VERSION = '0.0104';
 
 use strictures 2;
 use Moo;
@@ -74,6 +74,33 @@ has _canada => (
     },
 );
 
+has _netherlands => (
+    is       => 'ro',
+    init_arg => undef,
+    default  => sub {
+      {
+        DR  => [qw(OV FR GR)],
+        FL  => [qw(OV)],
+        FR  => [qw(FL GR DR OV)],
+        GE  => [qw(LI NB ZH UT OV)],
+        GR  => [qw(DR FR)],
+        LI  => [qw(NB GE)],
+        NB  => [qw(ZE ZH GE LI)],
+        NH  => [qw(ZH UT)],
+        OV  => [qw(GE FL FR DR)],
+        UT  => [qw(ZH NH GE)],
+        ZE  => [qw(NB)],
+        ZH  => [qw(NH UT GE NB)],
+        AW  => [],
+        CW  => [],
+        SX  => [],
+        BQ1 => [],
+        BQ2 => [],
+        BQ3 => [],
+      }
+    },
+);
+
 has _usa => (
     is       => 'ro',
     init_arg => undef,
@@ -163,20 +190,21 @@ Geography::States::Borders - Return the borders of states and provinces
 
 =head1 VERSION
 
-version 0.0103
+version 0.0104
 
 =head1 SYNOPSIS
 
   use Geography::States::Borders ();
-  my $geo = Geography::States::Borders->new(country => 'USA');
-  my $states = $geo->borders('HI'); # empty list
-  $states = $geo->borders('OR');    # CA ID NV WA
+  my $geo = Geography::States::Borders->new(country => 'Netherlands');
+  my $states = $geo->borders('AW'); # empty list
+  $states = $geo->borders('UT');    # ZH NH GE
 
 =head1 DESCRIPTION
 
 C<Geography::States::Borders> returns the borders of states and provinces.
 
-* Currently the only recognized countries are Canada, Brazil, and the USA.
+* Currently the only recognized countries are Canada, Brazil, The
+Netherlands, and the USA.
 
 =head1 ATTRIBUTES
 
